@@ -175,11 +175,17 @@ effects<-match.arg(effects)
 moments<-match.arg(moments)
 indes<-index
 
- if(!is.null(index)) {
+ #if(!is.null(index)) {
     #require(plm)
-    data <- plm.data(data, index)
-    }
-  
+ #   data <- plm.data(data, index)
+ #   }
+
+ ## substituted module based on plm.data (deprecated)
+ ## with one based on pdata.frame
+  if(!("pdata.frame" %in% class(data))) {
+    data <- pdata.frame(data, index)
+  }   
+
   index <- data[,1]
   tindex <- data[,2]
 
@@ -656,10 +662,16 @@ effects<-match.arg(effects)
 moments<-match.arg(moments)
 indes<-index
 
- if(!is.null(index)) {
+ #if(!is.null(index)) {
     #require(plm)
-    data <- plm.data(data, index)
-    }
+ #   data <- plm.data(data, index)
+ #   }
+
+ ## substituted module based on plm.data (deprecated)
+ ## with one based on pdata.frame
+  if(!("pdata.frame" %in% class(data))) {
+    data <- pdata.frame(data, index)
+  } 
   
   index <- data[,1]
   tindex <- data[,2]
